pub struct ModHeader {
pub title: String,
pub samples: Vec<Sample>,
pub song_length: u8,
pub restart: u8,
pub order: Vec<u8>,
pub signature: [u8; 4],
pub channels: u8,
pub n_patterns: u8,
}Fields
title: Stringsamples: Vec<Sample>song_length: u8restart: u8order: Vec<u8>signature: [u8; 4]channels: u8n_patterns: u8Number of distinct patterns referenced by the order table.
Implementations
Sourceimpl ModHeader
impl ModHeader
Sourcepub fn pattern_data_offset(&self) -> usize
pub fn pattern_data_offset(&self) -> usize
Total size of the header block preceding sample data (in bytes).
Sourcepub fn pattern_data_size(&self) -> usize
pub fn pattern_data_size(&self) -> usize
Size of the pattern data region in bytes.
Sourcepub fn sample_data_offset(&self) -> usize
pub fn sample_data_offset(&self) -> usize
Absolute offset where sample bodies begin.